@@ -4,7 +4,8 @@
 Python FIGlet adaption
 """
 
-from __future__ import print_function
+from __future__ import print_function, unicode_literals
+
 import pkg_resources
 import re
 import sys
